# [通义星尘](https://tongyi.aliyun.com/xingchen) Python SDK

- API 版本: v2
- Package 版本: 1.0.5

## 运行环境

Python 3.7+

## 安装/使用

### 安装

```sh
pip install xingchen==1.0.5
```

## 使用

认证信息可在[通义星尘/接入管理](https://tongyi.aliyun.com/xingchen/accessManagement)官网创建。

```python

import unittest

from xingchen import Configuration, ApiClient, ChatApiSub, ChatReqParams, CharacterKey, Message, UserProfile, \
    ModelParameters


def build_chat_param():
    return ChatReqParams(
        bot_profile=CharacterKey(
            character_id="c39797a35ad243f1a85baaa6e1ec37e0",
            version=1
        ),
        model_parameters=ModelParameters(
            top_p=0.8,    
            temperature=0.8,
            seed=1683806810
        ),
        messages=[
            Message(
                name='小明',
                role='user',
                content='你叫什么名字？'
            ),
            Message(
                name='小婉',
                role='assistant',
                content='我叫小婉啊。'
            ),
            Message(
                name='小明',
                role='user',
                content='你今年多大?'
            ),
            Message(
                name='小婉',
                role='assistant',
                content='我今年17岁了。'
            ),
            Message(
                name='小明',
                role='user',
                content='可以详细介绍浙江有哪些好玩的地方吗？'
            )
        ],
        user_profile=UserProfile(
            user_id='123456789',
            user_name='小明'
        )
    )


class Test(unittest.TestCase):

    @staticmethod
    def init_client():
        configuration = Configuration(
            host="https://nlp.aliyuncs.com"
        )
        configuration.access_token = "{API-KEY}"
        with ApiClient(configuration) as api_client:
            api_instance = ChatApiSub(api_client)
        return api_instance

    # 非流式回复
    def test_chat_sync(self):
        api = self.init_client()
        chat_param = build_chat_param()
        res = api.chat(chat_param)
        print(res.to_str())

    # 流式回复
    def test_chat_async(self):
        # 用户对话
        api = self.init_client()
        chat_param = build_chat_param()
        chat_param.streaming = True
        responses = api.chat(chat_param)
        for res in responses:
            print(res)


```

## [API文档](https://tongyi.aliyun.com/xingchen/document/interface_description)

请求地址 *https://nlp.aliyuncs.com*

Class | Method | HTTP request | 描述
------------ | ------------- | ------------- | -------------
*CharacterApiSub* | [**character_details**](docs/CharacterApiSub.md#character_details) | **GET** /v2/api/character/details | 角色详情
*CharacterApiSub* | [**character_details1**](docs/CharacterApiSub.md#character_details1) | **GET** /v1/api/character/details | 角色详情
*CharacterApiSub* | [**create**](docs/CharacterApiSub.md#create) | **POST** /v1/api/character/create | 创建角色
*CharacterApiSub* | [**create1**](docs/CharacterApiSub.md#create1) | **POST** /v2/api/character/create | 创建角色
*CharacterApiSub* | [**create_or_update_version**](docs/CharacterApiSub.md#create_or_update_version) | **PUT** /v1/api/character/createOrUpdateVersion | 创建或更新角色版本
*CharacterApiSub* | [**create_or_update_version1**](docs/CharacterApiSub.md#create_or_update_version1) | **PUT** /v2/api/character/createOrUpdateVersion | 创建或更新角色版本
*CharacterApiSub* | [**delete**](docs/CharacterApiSub.md#delete) | **DELETE** /v1/api/character/delete | 删除角色
*CharacterApiSub* | [**delete1**](docs/CharacterApiSub.md#delete1) | **DELETE** /v2/api/character/delete | 删除角色
*CharacterApiSub* | [**list_character_versions**](docs/CharacterApiSub.md#list_character_versions) | **GET** /v1/api/character/versions/{characterId} | 角色版本列表
*CharacterApiSub* | [**list_character_versions1**](docs/CharacterApiSub.md#list_character_versions1) | **GET** /v2/api/character/versions/{characterId} | 角色版本列表
*CharacterApiSub* | [**recommend_character_version**](docs/CharacterApiSub.md#recommend_character_version) | **GET** /v2/api/character/newversion/recommend/{characterId} | 角色版本列表
*CharacterApiSub* | [**recommend_character_version1**](docs/CharacterApiSub.md#recommend_character_version1) | **GET** /v1/api/character/newversion/recommend/{characterId} | 角色版本列表
*CharacterApiSub* | [**search**](docs/CharacterApiSub.md#search) | **POST** /v2/api/character/search | 查询角色
*CharacterApiSub* | [**search1**](docs/CharacterApiSub.md#search1) | **POST** /v1/api/character/search | 查询角色
*CharacterApiSub* | [**update**](docs/CharacterApiSub.md#update) | **PUT** /v2/api/character/update | 更新角色信息
*CharacterApiSub* | [**update1**](docs/CharacterApiSub.md#update1) | **PUT** /v1/api/character/update | 更新角色信息
*ChatApiSub* | [**chat**](docs/ChatApiSub.md#chat) | **POST** /v1/api/chat/send | 用户对话
*ChatApiSub* | [**chat_v2**](docs/ChatApiSub.md#chat_v2) | **POST** /v2/api/chat/send | 用户对话v2
*ChatApiSub* | [**custom_chat**](docs/ChatApiSub.md#custom_chat) | **POST** /v2/api/chat/generate | 用户对话
*ChatApiSub* | [**custom_chat1**](docs/ChatApiSub.md#custom_chat1) | **POST** /v1/api/chat/generate | 用户对话
*ChatMessageApiSub* | [**chat_histories**](docs/ChatMessageApiSub.md#chat_histories) | **POST** /v1/api/chat/message/histories | 对话历史
*ChatMessageApiSub* | [**chat_histories1**](docs/ChatMessageApiSub.md#chat_histories1) | **POST** /v2/api/chat/message/histories | 对话历史
*ChatMessageApiSub* | [**chat_histories2**](docs/ChatMessageApiSub.md#chat_histories2) | **GET** /v1/api/chat/history/{characterId} | 对话历史
*ChatMessageApiSub* | [**chat_histories3**](docs/ChatMessageApiSub.md#chat_histories3) | **GET** /v2/api/chat/history/{characterId} | 对话历史
*ChatMessageApiSub* | [**rate_message**](docs/ChatMessageApiSub.md#rate_message) | **POST** /v2/api/chat/rating | 消息评分
*ChatMessageApiSub* | [**rate_message1**](docs/ChatMessageApiSub.md#rate_message1) | **POST** /v1/api/chat/rating | 消息评分
*ChatMessageApiSub* | [**sys_reminder**](docs/ChatMessageApiSub.md#sys_reminder) | **POST** /v1/api/chat/reminder | 
*ChatMessageApiSub* | [**sys_reminder1**](docs/ChatMessageApiSub.md#sys_reminder1) | **POST** /v2/api/chat/reminder | 


## 请求/响应参数对象

 - [AdvancedSettings](docs/AdvancedSettings.md)
 - [BaseChatRequest](docs/BaseChatRequest.md)
 - [BaseChatRequestAcaChatExtParam](docs/BaseChatRequestAcaChatExtParam.md)
 - [CharacterAdvancedConfig](docs/CharacterAdvancedConfig.md)
 - [CharacterCreateDTO](docs/CharacterCreateDTO.md)
 - [CharacterDTO](docs/CharacterDTO.md)
 - [CharacterKey](docs/CharacterKey.md)
 - [CharacterPermissionConfig](docs/CharacterPermissionConfig.md)
 - [CharacterQueryDTO](docs/CharacterQueryDTO.md)
 - [CharacterQueryWhere](docs/CharacterQueryWhere.md)
 - [CharacterUpdateDTO](docs/CharacterUpdateDTO.md)
 - [CharacterVersionCreateOrUpdateDTO](docs/CharacterVersionCreateOrUpdateDTO.md)
 - [ChatHistoryQueryDTO](docs/ChatHistoryQueryDTO.md)
 - [ChatHistoryQueryWhere](docs/ChatHistoryQueryWhere.md)
 - [ChatMessageDTO](docs/ChatMessageDTO.md)
 - [ChatReqParams](docs/ChatReqParams.md)
 - [ChatRoomUserDTO](docs/ChatRoomUserDTO.md)
 - [Context](docs/Context.md)
 - [FileInfoVO](docs/FileInfoVO.md)
 - [GatewayContext](docs/GatewayContext.md)
 - [GatewayIssuedParams](docs/GatewayIssuedParams.md)
 - [Input](docs/Input.md)
 - [Message](docs/Message.md)
 - [MessageRatingRequest](docs/MessageRatingRequest.md)
 - [Meta](docs/Meta.md)
 - [ModelParameter](docs/ModelParameter.md)
 - [ModelParameters](docs/ModelParameters.md)
 - [PageResultCharacterDTO](docs/PageResultCharacterDTO.md)
 - [PageResultChatMessageDTO](docs/PageResultChatMessageDTO.md)
 - [Repository](docs/Repository.md)
 - [RepositoryInfo](docs/RepositoryInfo.md)
 - [ResultDTOBoolean](docs/ResultDTOBoolean.md)
 - [ResultDTOCharacterDTO](docs/ResultDTOCharacterDTO.md)
 - [ResultDTOCharacterKey](docs/ResultDTOCharacterKey.md)
 - [ResultDTOListCharacterDTO](docs/ResultDTOListCharacterDTO.md)
 - [ResultDTOPageResultCharacterDTO](docs/ResultDTOPageResultCharacterDTO.md)
 - [ResultDTOPageResultChatMessageDTO](docs/ResultDTOPageResultChatMessageDTO.md)
 - [Scenario](docs/Scenario.md)
 - [SysReminderRequest](docs/SysReminderRequest.md)
 - [UserProfile](docs/UserProfile.md)
